@@ -1,7 +1,7 @@
 package App::lcpan::Call;
 
-our $DATE = '2015-12-18'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-01-05'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,7 +17,17 @@ $SPEC{call_lcpan_script} = {
     v => 1.1,
     summary => '"Call" lcpan script',
     args => {
-        # XXX max_index_age (default 14 days)
+        max_age => {
+            summary => 'Maximum index age (in seconds)',
+            schema => 'duration',
+            'x.perl.coerce_to' => 'int(secs)',
+            description => <<'_',
+
+If unspecified, will look at `LCPAN_MAX_AGE` environment variable. If that is
+also undefined, will default to 14 days.
+
+_
+        },
         argv => {
             schema => ['array*', of=>'str*'],
             default => [],
@@ -42,9 +52,11 @@ sub call_lcpan_script {
         die "Can't 'lcpan stats': $res->[0] - $res->[1]\n"
             unless $res->[0] == 200;
         my $stats = $res->[2];
-        if ((time - $stats->{raw_last_index_time}) > 14*86400) {
-            die "lcpan index is over 14 days old, please refresh it first ".
-                "with 'lcpan update'\n";
+        my $max_age = $args{max_age} // $ENV{LCPAN_MAX_AGE} // 14*86400;
+        my $max_age_in_days = sprintf("%f", $max_age / 86400);
+        if ((time - $stats->{raw_last_index_time}) > $max_age) {
+            die "lcpan index is over $max_age_in_days day(s) old, ".
+                "please refresh it first with 'lcpan update'\n";
         }
     }
 
@@ -72,7 +84,7 @@ App::lcpan::Call - "Call" lcpan script
 
 =head1 VERSION
 
-This document describes version 0.05 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2015-12-18.
+This document describes version 0.06 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2016-01-05.
 
 =head1 FUNCTIONS
 
@@ -89,6 +101,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<argv> => I<array[str]> (default: [])
 
+=item * B<max_age> => I<duration>
+
+Maximum index age (in seconds).
+
+If unspecified, will look at C<LCPAN_MAX_AGE> environment variable. If that is
+also undefined, will default to 14 days.
+
 =back
 
 Return value:  (any)
@@ -115,7 +134,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
